class MoviesController < ApplicationController
  before_filter :require_admin, :except => [:index, :show]
  
  def index
    @movies = Movie.search(params[:search])
  end
  
  def show
    @movie = Movie.find(params[:id])
    @reviews = @movie.reviews.filter_stars(params[:filter])
    @theaters = @movie.theaters.currently_playing
  end
  
  def new
    @movie = Movie.new
    @movie.showings.build
  end
  
  def create
    @movie = Movie.new(params[:movie])
    if @movie.save
      flash[:notice] = "Successfully created movie."
      redirect_to movies_path
    else
      render :action => 'new'
    end
  end
  
  def edit
    @movie = Movie.find(params[:id])
  end
  
  def update
    @movie = Movie.find(params[:id])
    if @movie.update_attributes(params[:movie])
      flash[:notice] = "Successfully updated movie."
      redirect_to movies_path
    else
      render :action => 'edit'
    end
  end
  
  def destroy
    @movie = Movie.find(params[:id])
    @movie.destroy
    flash[:notice] = "Successfully destroyed movie."
    redirect_to movies_path
  end
end
